@@ -7,18 +7,16 @@
 #include "messagequeuejob.h"
 
 #include "kmailtransportakonadi/transportattribute.h"
-#include "transport.h"
-#include "transportmanager.h"
 
 #include "mailtransportakonadi_debug.h"
 #include <KLocalizedString>
 
+#include <Akonadi/AddressAttribute>
 #include <Akonadi/Item>
 #include <Akonadi/ItemCreateJob>
-#include <addressattribute.h>
-#include <messageflags.h>
-#include <specialmailcollections.h>
-#include <specialmailcollectionsrequestjob.h>
+#include <Akonadi/MessageFlags>
+#include <Akonadi/SpecialMailCollections>
+#include <Akonadi/SpecialMailCollectionsRequestJob>
 
 using namespace Akonadi;
 using namespace KMime;
@@ -71,14 +69,6 @@ bool MessageQueueJobPrivate::validate()
         return false;
     }
 
-    const int transport = transportAttribute.transportId();
-    if (TransportManager::self()->transportById(transport, false) == nullptr) {
-        q->setError(KJob::UserDefinedError);
-        q->setErrorText(i18n("Message has invalid transport."));
-        q->emitResult();
-        return false;
-    }
-
     if (sentBehaviourAttribute.sentBehaviour() == SentBehaviourAttribute::MoveToCollection && !(sentBehaviourAttribute.moveToCollection().isValid())) {
         q->setError(KJob::UserDefinedError);
         q->setErrorText(i18n("Message has invalid sent-mail folder."));
